#!/usr/share/ucs-test/runner pytest-3 -s -l -v
## -*- coding: utf-8 -*-
## desc: Check test app login, get access token and verify self disclosure user metadata
## tags: [ucsschool-id-broker]
## packages: [id-broker-provisioning-api-plugin]
## exposure: safe


import pytest
from utils import get_self_disclosure_metadata, get_token_from_test_app_logon


@pytest.mark.parametrize(
    "uid",
    [
        "Traeger1-stud1",
        "Traeger1-teach1",
        "Traeger2-stud1",
        "Traeger2-teach1",
    ],
)
def test_test_app_login(selenium, udm, uid):
    traeger = uid.split("-")[0]
    username = uid.split("-", 1)[1]
    kdc_idp_hint = traeger.lower()
    password = "univention"

    tokens = get_token_from_test_app_logon(selenium, username, password, kdc_idp_hint)
    user_metadata = get_self_disclosure_metadata(tokens["access_token"])

    udm_mod = udm.get("users/user")
    broker_user = list(udm_mod.search(f"uid={uid}"))[0]
    assert user_metadata["username"] == "{}.{}".format(
        broker_user.props.firstname, broker_user.props.lastname
    )
    assert user_metadata["firstname"] == broker_user.props.firstname
    assert user_metadata["lastname"] == broker_user.props.lastname
    assert user_metadata["school_id"] in [
        school.replace(f"{traeger}-", "") for school in broker_user.props.school
    ]
    assert user_metadata["school_authority"] == broker_user.props.ucsschoolSourceUID
    assert user_metadata["type"] in [role.split(":")[0] for role in broker_user.props.ucsschoolRole]
